@import 'mixins';

$medium-down: '#{$screen} and (max-width:#{upper-bound($medium-range)})';

$sidebar-bg: rgb(250, 250, 250) !default;
$sidebar-left-large-width: 250px !default;
$sidebar-left-medium-width: 200px !default;
$sidebar-right-max-width: 220px !default;
$sidebar-gutter-spacing: 10px !default;

$sidebar-link-active-color: $anchor-font-color !default;
$sidebar-link-hover-color: $anchor-font-color-hover !default;
$sidebar-link-active-bg: rgba(0, 64, 84, 0.05) !default;
$sidebar-link-hover-bg: rgba(0, 64, 84, 0.03) !default;

$background-overlay-color: rgba(0, 0, 0, 0.7);

// scss-lint:disable ColorVariable
$loader-colors: rgba(0, 0, 0, 1), rgba(0, 0, 0, 0.8), rgba(0, 0, 0, 0.6),
  rgba(0, 0, 0, 0.4), rgba(0, 0, 0, 0.2) !default;
// scss-lint:enable ColorVariable

$loader-subicon: '\0025CF' !default;

$fixed-modal-width: 400px !default;

// Levels
$level-1: 100;

// Copied from portal
$color-error: #d60026;
