$row-width: 100%;
$crumb-bg: rgba(0, 0, 0, 0) !default;
$crumb-padding: 0 !default;
$crumb-border-size: 0 !default;
$crumb-radius: 0 !default;
$alert-padding-top: 0.5rem !default;
$alert-bottom-margin: 1em !default;
$body-font-color: #444444 !default;
$tooltip-font-size: 0.8em !default;
